@@ -4,14 +4,14 @@ use warnings;
 
 package Git::Wrapper;
 #ABSTRACT: Wrap git(7) command-line interface
-$Git::Wrapper::VERSION = '0.039'; # TRIAL
+$Git::Wrapper::VERSION = '0.040'; # TRIAL
 our $DEBUG=0;
 
 # Prevent ANSI color with extreme prejudice
 # https://github.com/genehack/Git-Wrapper/issues/13
 delete $ENV{GIT_PAGER_IN_USE};
 
-use File::pushd;
+use File::chdir;
 use File::Temp;
 use IPC::Open3      qw();
 use Scalar::Util    qw(blessed);
@@ -83,7 +83,7 @@ sub RUN {
   my( @out , @err );
 
   {
-    my $d = pushd $self->dir unless $cmd eq 'clone';
+    local $CWD = $self->dir unless $cmd eq 'clone';
 
     my ($wtr, $rdr, $err);
 
@@ -388,7 +388,7 @@ Git::Wrapper - Wrap git(7) command-line interface
 
 =head1 VERSION
 
-version 0.039
+version 0.040
 
 =head1 SYNOPSIS
 
